<?php
/**
 * Smarty plugin
 * @package Smarty
 * @subpackage plugins
 */


/**
 * Smarty {rand} function plugin
 *
 * Type:     function<br>
 * Name:     rand<br>
 * Date:     2010-05-21<br>
 * Purpose:  generate random number in template<br>
 * Input:
 *         - min = integer - minimum random number
 *         - max = integer - maximum random number
 *         - print = boolean - print var or not. default is true
 *         - assign = string - assigns to template var instead of
 *                    printed.
 *
 * Examples:<br>
 * <pre>
 * {rand min=5 max=15}
 * {rand min=7 max=24 assign='random'}
 * </pre>
 * @author   Markus Zierhut <markus.zierhut@zierhut-networks.de>
 * @param array
 * @param Smarty
 * @return string
 */
function smarty_function_rand($params, &$smarty)
{
    
	$print = ( isset( $params[ 'print' ] ) ) ? (bool)$params[ 'print' ] : true;
	
	// be sure min parameter is present
    if( empty( $params[ 'min' ] ) ) {
        $smarty->trigger_error( 'rand: missing min parameter' );
        return;
    }

    // be sure max parameter is present
    if( empty( $params[ 'max' ] ) ) {
        $smarty->trigger_error( 'rand: missing max parameter' );
        return;
    }
    
    $min = $params[ 'min' ];
    $max = $params[ 'max' ];
    
    $rand = mt_rand( $min, $max );
    
    if( isset( $params[ 'assign' ] ) ) {
        $print = false;
        $smarty->assign( $params[ 'assign' ], $rand );
    }

    if( $print ) {
        $retval = $rand;
    } else {
        $retval = null;
    }

    return $retval;
    
}

/* vim: set expandtab: */

?>
